@@ -1,5 +1,7 @@
 import cv2
+import numpy as np
 from jcopvision.exception import IncorrectExtensionError
+from jcopvision.utils._denorm import denorm_pixel
 
 
 class BaseWriter:
@@ -9,6 +11,9 @@ class BaseWriter:
         self._writer = cv2.VideoWriter(output_path, fourcc, fps, (self.width, self.height))
 
     def write(self, frame):
+        if frame.dtype == np.float32:
+            frame = denorm_pixel(frame)
+
         h, w, c = frame.shape
         if (w != self.width) | (h != self.height):
             frame = cv2.resize(frame, (self.width, self.height))
